ble_gap_event__bindgen_ty_1__bindgen_ty_2

Struct ble_gap_event__bindgen_ty_1__bindgen_ty_2 

#[repr(C)]
pub struct ble_gap_event__bindgen_ty_1__bindgen_ty_2 { pub status: i32, pub conn_handle: u16, }
Represents a successful Link establishment attempt. Sometimes, in noisy environment, even if BLE_GAP_EVENT_CONNECT is posted, the link syncronization procedure may fail and link gets disconnected with reason 0x3E. Application can wait for below event to ensure the link syncronization is completed. Valid for the following event types: o BLE_GAP_EVENT_LINK_ESTAB

Fields

status: i32

The final status of the link establishment; o 0: the connection was successfully established. o BLE host error code: the connection attempt failed for the specified reason.

conn_handle: u16

The handle of the relevant connection.