#[repr(C)]pub struct ble_gatt_chr_def {
pub uuid: *const ble_uuid_t,
pub access_cb: Option<unsafe extern "C" fn(u16, u16, *mut ble_gatt_access_ctxt, *mut c_void) -> i32>,
pub arg: *mut c_void,
pub descriptors: *mut ble_gatt_dsc_def,
pub flags: u32,
pub min_key_size: u8,
pub val_handle: *mut u16,
pub cpfd: *mut ble_gatt_cpfd,
}Expand description
Represents the definition of a GATT characteristic.
Fields
uuid: *const ble_uuid_tPointer to characteristic UUID; use BLE_UUIDxx_DECLARE macros to declare proper UUID; NULL if there are no more characteristics in the service.
access_cb: Option<unsafe extern "C" fn(u16, u16, *mut ble_gatt_access_ctxt, *mut c_void) -> i32>Callback that gets executed when this characteristic is read or written.
arg: *mut c_voidOptional argument for callback.
descriptors: *mut ble_gatt_dsc_defArray of this characteristic’s descriptors. NULL if no descriptors. Do not include CCCD; it gets added automatically if this characteristic’s notify or indicate flag is set.
flags: u32Specifies the set of permitted operations for this characteristic.
min_key_size: u8Specifies minimum required key size to access this characteristic.
val_handle: *mut u16At registration time, this is filled in with the characteristic’s value attribute handle.
The attribute handle for CCCD is val_handle + 1
cpfd: *mut ble_gatt_cpfdClient Presentation Format Descriptors