esp_mqtt5_subscribe_property_config_t

Struct esp_mqtt5_subscribe_property_config_t 

#[repr(C)]
pub struct esp_mqtt5_subscribe_property_config_t { pub subscribe_id: u16, pub no_local_flag: bool, pub retain_as_published_flag: bool, pub retain_handle: u8, pub is_share_subscribe: bool, pub share_name: *const u8, pub user_property: *mut mqtt5_user_property_list_t, }
MQTT5 protocol subscribe properties configuration, more details refer to MQTT5 protocol document section 3.8.2.1

Fields

subscribe_id: u16

< A variable byte represents the identifier of the subscription

no_local_flag: bool

< Subscription Option to allow that server publish message that client sent

retain_as_published_flag: bool

< Subscription Option to keep the retain flag as published option

retain_handle: u8

< Subscription Option to handle retain option

is_share_subscribe: bool

< Whether subscribe is a shared subscription

share_name: *const u8

< The name of shared subscription which is a part of $share/{share_name}/{topic}

user_property: *mut mqtt5_user_property_list_t

< The handle for user property, call function esp_mqtt5_client_set_user_property to set it