#[repr(C)]pub struct esp_mqtt5_unsubscribe_property_config_t {
pub is_share_subscribe: bool,
pub share_name: *const u8,
pub user_property: *mut mqtt5_user_property_list_t,
}Expand description
MQTT5 protocol unsubscribe properties configuration, more details refer to MQTT5 protocol document section 3.10.2.1
Fields
< Whether subscribe is a shared subscription
< The name of shared subscription which is a part of $share/{share_name}/{topic}
user_property: *mut mqtt5_user_property_list_t< The handle for user property, call function esp_mqtt5_client_set_user_property to set it