#[repr(C)]pub struct ble_gap_event__bindgen_ty_1__bindgen_ty_22 {
pub status: u8,
pub conn_handle: u16,
pub max_remote_page: u8,
pub max_valid_page: u8,
pub le_features: [u8; 248],
}Expand description
Represents a read all remote features complet event Valid for the following event types: o BLE_GAP_EVENT_RD_ALL_REM_FEAT
Fields
status: u8Status indicating the reason for failure. Refer to HCI error codes for detailed status values.
conn_handle: u16Connection handle identifying the connection.
max_remote_page: u8Highest numbered page of remote device’s supported LE features that contains atleast one bit set to 1
max_valid_page: u8Number of highest numbered page of LE features that contains valid data
le_features: [u8; 248]Bit Mask List of LE features